#!/usr/bin/gnuplot
set macros
PREFIJO = '#prefijo#'

#-----------------------------------------------------------------------------------------------------coordenadas
z_min = #z_min#
z_max = #z_max#
x_min = #x_min#
x_max = #x_max#


set xrange [z_min : z_max]
set yrange [x_min : x_max]

#coordenadas de elementos de la leyenda

x_f=5.3
y_f=1.8
dy_f=0.4
dx_f=0.2

x_color = 6.1
y_color = y_f-dy_f
dy_color = 15.5*dy_f

#-----------------------------------------------------------------------------------------------------tamaño y presentación
unset key
unset title
unset border

set xlabel '\lf'
set ylabel '\lg'

set xtics
set ytics
#set xtics 1 out
#set ytics 1 out
set size 0.73, 1


escala=1
#-----------------------------------------------------------------------------------------------------colores y estilos

load 'YlGnBu.plt'
set palette negative
set colorbox user origin 0.7,.05 noborder

ENTRADA = 'ExH ExB ExM maximos rayo params params divExH divExB intensidad · IExH IExB E2_IExH IExB_IExH'
SALIDA = '· · · · · · · divExH.tex divExB.tex intensidad.tex · IExH.tex IExB.tex E2_IExH.tex IExB_IExH.tex'
COLOR = '#be3b3b #c4a000 #73d216 #8c0586 #fa70f4 #6fa23c #5c3566 · · · #888a85 · · · ·'
LEYENDA = '\la \lb · · · \lc \ld · · \le ·'

color(x) = word(COLOR, x)
leyenda(x) = word(LEYENDA, x)

ExH=1
ExB=2
ExM=3
MAXIMOS=4
RAYO=5
ANGULO_K=6
ANGULO_S=7
DIVExH=8
DIVExB=9
INTENSIDAD=10
INTERFAZ=11
IExH = 12
IExB = 13
E2_IExH = 14
IExB_IExH = 15


set style line ExB lc rgb color(ExB) lt 1 lw 2
set style line ExH lc rgb color(ExH) lt 1 lw 2
set style line ExM lc rgb color(ExM) lt 1 lw 2
set style line ANGULO_K lc rgb color(ANGULO_K) lt 1
set style line ANGULO_S lc rgb color(ANGULO_S) lt 1
set style line MAXIMOS lt 1 lw 1 lc rgb color(MAXIMOS)
set style line RAYO  lt 1 lw 1 lc rgb color(RAYO)

set style arrow INTERFAZ nohead lc rgb color(INTERFAZ) lw 0.5 lt 2
set style arrow ANGULO_K nohead ls ANGULO_K
set style arrow ANGULO_S nohead ls ANGULO_S

MAPA_COLOR = 'nonuniform matrix using 1:2:3  with image'
CAMPO_VECTORIAL = 'u ($1):($2):(escala*$3):(escala*$4) with vectors'
INTERPOLACION = 'smooth bezier'

GRAF_ExH=1
GRAF_ExB=2
GRAF_ExM=4
GRAF_MAXIMOS=8
GRAF_RAYO=16
GRAF_ANGULO_K=32
GRAF_ANGULO_S=64
GRAF_DIVExH=128
GRAF_DIVExB=256
GRAF_INTENSIDAD=512
GRAF_INTERFAZ=1024
GRAF_IExH = 2048
GRAF_IExB = 4096
GRAF_E2_IExH = 8192
GRAF_IExB_IExH = 16384

graf = #graf#

entrada(x) = PREFIJO . '-' . word(ENTRADA, x) . '.dat'
salida(x) = PREFIJO . '-' . word(SALIDA, x)
opc(x) = (graf & 2**(x-1)) == 2**(x-1)


#-----------------------------------------------------------------------------------------------------ociones para graficar




#leer ángulos de incidencia y refracción
#set term dumb
#plot entrada(ANGULO_K) using (ai=$1, Ar=$2, ar=$3)
stats entrada(ANGULO_K) using 1 nooutput
ai=STATS_max
stats entrada(ANGULO_K) using 2 nooutput
Ar=STATS_max
stats entrada(ANGULO_K) using 3 nooutput
ar=STATS_max


set term epslatex



#-----------------------------------------------------------------------------------------------------divergencias

if(opc(DIVExB)){
	set output salida(DIVExB)
	plot entrada(DIVExB) @MAPA_COLOR 
}

if(opc(DIVExH)){
	set output salida(DIVExH)
	plot entrada(DIVExH) @MAPA_COLOR
}

#-----------------------------------------------------------------------------------------------------intensidad


if(opc(IExH)){
	set output salida(IExH)
	plot entrada(IExH) @MAPA_COLOR
}

if(opc(IExB)){
	set output salida(IExB)
	plot entrada(IExB) @MAPA_COLOR
}

if(opc(E2_IExH)){
	set output salida(E2_IExH)
	plot entrada(E2_IExH) @MAPA_COLOR
}

if(opc(IExB_IExH)){
	set output salida(IExB_IExH)
	plot entrada(IExB_IExH) @MAPA_COLOR
}

if(0==1){
	set output PREFIJO.'-fase.pdf'
	plot PREFIJO.'-fase.dat' @MAPA_COLOR
	
	set output PREFIJO.'-gradiente-fase.pdf'
	set zrange [0 : 2]
	plot PREFIJO.'-gradiente-fase.dat' @MAPA_COLOR
}

#-----------------------------------------------------------------------------------------------------densidad de energía

set output salida(INTENSIDAD)

set multiplot

if(opc(INTENSIDAD)){
	set cblabel leyenda(INTENSIDAD)
	set cbtics 4
	plot entrada(INTENSIDAD) @MAPA_COLOR
}

if(opc(INTERFAZ)){
	set arrow from 0, x_max to 0, x_min arrowstyle INTERFAZ
}

if(opc(ExB)){
	plot entrada(ExB) @CAMPO_VECTORIAL ls ExB
	
	set arrow from x_f, y_f + 2*dy_f to x_f, y_f + 3*dy_f ls ExB
	set label leyenda(ExB) at x_f + dx_f, y_f + 2.5*dy_f
}

if(opc(ExH)){
	plot entrada(ExH) @CAMPO_VECTORIAL ls ExH
	
	set arrow from x_f,y_f to x_f, y_f+dy_f ls ExH
	set label leyenda(ExH) at x_f + dx_f, y_f+dy_f/2
}

if(opc(ExM)){
	plot entrada(ExM) @CAMPO_VECTORIAL ls ExM
}

if(opc(MAXIMOS)){
	plot entrada(MAXIMOS) ls MAXIMOS @INTERPOLACION
}

if(opc(RAYO)){
	plot entrada(RAYOS) ls RAYO @INTERPOLACION
}

#-----------------------------------------------------------------------------------------------------direcciones de k principal y s principal 

t_min = 0
t_max = (z_max - z_min) / 2

set parametric
set trange [0:100]
set yrange [x_min : x_max]
set xrange [z_min : z_max]
	
if(opc(ANGULO_S)){
	plot t, tan(ar)*t ls ANGULO_S
	
	set arrow from x_f, y_f + 6*dy_f to x_f, y_f + 7*dy_f arrowstyle ANGULO_S
	set label leyenda(ANGULO_S) at x_f + dx_f, y_f + 6.5*dy_f
}

if(opc(ANGULO_K)){
	set arrow from x_f, y_f + 4*dy_f to x_f, y_f + 5*dy_f arrowstyle ANGULO_K
	set label leyenda(ANGULO_K) at x_f + dx_f, y_f + 4.5*dy_f
	
	plot t, tan(Ar)*t ls ANGULO_K
	plot -t, -tan(ai)*t ls ANGULO_K
}

unset multiplot

